@@ -55,3 +55,16 @@ sub compare_binary_files {
   return 0;
 }
 
+sub display_file {
+  my ( $file ) = @_;
+  my $in;
+  if ( !open( $in, $file ) ) {
+    warn "Error: unable to open $file: $!\n";
+  }
+  else {
+    while (<$in>) {
+      print STDERR $_;
+    }
+    close($in);
+  }
+}
